const buildState = ({ theme, color, backgroundColor, borderColor }) => {
	return {
		color: color,
		backgroundColor: backgroundColor,
		borderColor: borderColor,
		boxShadow: `0 3px ${borderColor}`,
		'&.button--blank': {
			color: backgroundColor,
			backgroundColor: theme('colors.button.blank.background'),
			borderColor: theme('colors.button.blank.border'),
			boxShadow: `0 3px ${theme('colors.button.blank.border')}`
		},
		'&:active:not(:disabled)': {
			boxShadow: `0 0 ${borderColor}`,
			transform: 'translateY(3px)'
		}
	};
};

const button = (theme) => ({
	'.button': {
		padding: `${theme('spacing.2')} ${theme('spacing.4')}`,
		margin: `${theme('spacing.2')} auto`,
		display: 'flex',
		justifyContent: 'center',
		width: '100%',
		alignItems: 'center',
		borderRadius: theme('borderRadius.lg'),
		border: '1px solid',
		textTransform: 'uppercase',
		fontWeight: theme('fontWeight.normal'),
		'&--none': buildState({
			theme,
			color: theme('colors.button.none.color'),
			backgroundColor: theme('colors.button.none.background'),
			borderColor: theme('colors.button.none.border')
		}),
		'&--none.button--blank': {
			color: theme('colors.button.blank.color')
		},
		'&--info': buildState({
			theme,
			color: theme('colors.status.info.color'),
			backgroundColor: theme('colors.status.info.background'),
			borderColor: theme('colors.status.info.border')
		}),
		'&--success': buildState({
			theme,
			color: theme('colors.status.success.color'),
			backgroundColor: theme('colors.status.success.background'),
			borderColor: theme('colors.status.success.border')
		}),
		'&--warning': buildState({
			theme,
			color: theme('colors.status.warning.color'),
			backgroundColor: theme('colors.status.warning.background'),
			borderColor: theme('colors.status.warning.border')
		}),
		'&--error': buildState({
			theme,
			color: theme('colors.status.error.color'),
			backgroundColor: theme('colors.status.error.background'),
			borderColor: theme('colors.status.error.border')
		}),
		'&:disabled': {
			boxShadow: `0 0px ${theme('colors.button.disabled.border')}`,
			transform: 'translateY(3px)',
			cursor: 'not-allowed',
			color: theme('colors.button.disabled.color'),
			backgroundColor: theme('colors.button.disabled.background'),
			borderColor: theme('colors.button.disabled.border')
		},
		'&--large': {
			height: '48px',
			fontSize: '20px'
		},
		'&--medium': {
			height: '40px',
			fontSize: '14px'
		},
		'&--small': {
			height: '26px',
			fontSize: '12px'
		},
		'&--pressed': {
			boxShadow: 'none',
			transform: 'translateY(3px)'
		}
	}
});

module.exports = ({ addComponents, theme }) => {
	addComponents(button(theme));
};

module.exports.button = button;
